import * as Mqtt from 'mqtt'

class MqttMongo {
  private mqttClient : Mqtt.Client

  constructor() {
    this.mqttClient = Mqtt.connect(options['broker'])
    this.mqttClient.on('offline', () => { console.log("mqtt client is offline") })
    this.mqttClient.on('reconnect', () => { console.log("mqtt client is reconnecting") })
    this.mqttClient.on('close', () => { console.log("mqtt connection closed") })
  }

  exec(): void {
    this.mqttClient.on('connect', () => {
      console.log("mqtt client connected to broker")
      this.mqttClient.subscribe('MqttMongo/Command')
      this.mqttClient.publish('MqttMongo/Status', 'hello, started up')
    })

    this.mqttClient.on('message', (topic : string, message : string) => {
      console.log("message received")
      console.log("topic %s", topic)
      console.log("message %s", message)

      if (topic == "MqttMongo/Command" && message == "shutdown") {
        this.mqttClient.end()
      }
    })
  }
}


import options = require('commander')
options
  .version('0.0.1')
  .option('-b, --broker [broker url]', 'Broker URL', 'mqtt://mqttbroker')
  .parse(process.argv)

const mqttMongo = new MqttMongo()
mqttMongo.exec()

console.log("MqttMongo started")